/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* * ACCOUNT SYMBOL ICON                                                                                             * */
/* *                                                                                                                 * */
/* * This image is designed for 1:1 aspect ratio.                                                                    * */
/* *                                                                                                                 * */
/* * The variable [CAMERAZ] should be adjusted so the image is 570 pixels high when rendered at 800 x 800 pixels.    * */
/* * The variable [STROKEWIDTH] will be adjusted automatically to maintain consistent stroke widths for different    * */
/* * icons at different camera distances.                                                                            * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

//+w128 +h128 +ua
//-f +w800 +h800

#version 3.7;

global_settings {assumed_gamma 2.2}

#local CameraZ = 4.17;

camera {
   orthographic
   location <0, 0, -CameraZ>
   direction <0, 0, 1>
   scale <1, 4/3, 1>
   look_at <0, 0, 0>
} //camera

#include "colors.inc"

#background {<135, 130, 102> / 255}

#local SymbolColor_Outer = texture {pigment {color White} finish {emission 1}}
#local SymbolColor_Inner = texture {pigment {color <102 * .91, 98 * .91, 76 * .92> / 255} finish {emission 1}}

#local StrokeWidth = .2;

#local ReverseDirection = false;

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * MACROS                                                                                                          * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#macro Center_XY (Thing)

   #local Thing = object {Thing translate (-min_extent (Thing).x) * x}
   #local Thing = object {Thing translate (-max_extent (Thing).x / 2) * x}
   #local Thing = object {Thing translate (-max_extent (Thing).y) * y}
   #local Thing = object {Thing translate (-min_extent (Thing).y / 2) * y}

#end //#macro Center_XY

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * SYMBOLS                                                                                                         * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#if (ReverseDirection)
   #local SymbolAngle = -45;
#else
   #local SymbolAngle = 45;
#end //#if

#local StrokeWidth = StrokeWidth * CameraZ / 4;

#local SW2 = StrokeWidth / 2;

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

//Object variables:

#local LensRadius = 1.5;

#local ReflectionRadius = LensRadius * .9; //Inner curvature
#local ReflectionWidth = StrokeWidth * 1;
#local ReflectionDistance = 1.5; //Distance from the outer edge, multiple of StrokeWidth
#local ReflectionAngle = 90 - SymbolAngle * 2;

#local HandleLength = 1.75;
#local HandleWidthFactor = 1.75;
#local HandleRadius = .1;

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#local Reflection = object {
   difference {
      cylinder {<0, 0, -.3> <0, 0, .2>, LensRadius - StrokeWidth * (ReflectionDistance + 1)}
      cylinder {<0, 0, -.4> <0, 0, .3>, ReflectionRadius translate (-ReflectionRadius + LensRadius - StrokeWidth * (ReflectionDistance + 1) - ReflectionWidth) * x rotate ReflectionAngle * z}
   } //difference
   texture {SymbolColor_Outer}
} //object

#local Lens = object {
   union {
      cylinder {<0, 0, -.1> <0, 0, 0>, LensRadius texture {SymbolColor_Outer}}
      cylinder {<0, 0, -.2> <0, 0, .1>, LensRadius - StrokeWidth texture {SymbolColor_Inner}}
      object {Reflection}
   } //union
} //object

#local Handle = object {
   union {
      difference {
         box {<-SW2 * HandleWidthFactor, -LensRadius + StrokeWidth, -.1> <SW2 * HandleWidthFactor, -LensRadius - HandleLength, 0>}
         cylinder {<0, 0, -.1> <0, 0, 0>, LensRadius texture {SymbolColor_Outer}}
      } //difference
      cylinder {<0, 0, -.1> <0, 0, 0>, HandleRadius translate <-SW2 * HandleWidthFactor + HandleRadius, -LensRadius - HandleLength, 0>}
      cylinder {<0, 0, -.1> <0, 0, 0>, HandleRadius translate <SW2 * HandleWidthFactor - HandleRadius, -LensRadius - HandleLength, 0>}
      box {<-SW2 * HandleWidthFactor + HandleRadius, -LensRadius - HandleLength, -.1> <SW2 * HandleWidthFactor - HandleRadius, -LensRadius - HandleLength - HandleRadius, 0>}
   } //union
   texture {SymbolColor_Outer}
} //object

#local Search = object {
   union {
      object {Lens}
      object {Handle}
   } //union
   rotate SymbolAngle * z
} //object

Center_XY (Search)

object {Search}
