/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* * ACCOUNT SYMBOL ICON                                                                                             * */
/* *                                                                                                                 * */
/* * This image is designed for 1:1 aspect ratio.                                                                    * */
/* *                                                                                                                 * */
/* * The variable [CAMERAZ] should be adjusted so the image is 570 pixels high when rendered at 800 x 800 pixels.    * */
/* * The variable [STROKEWIDTH] will be adjusted automatically to maintain consistent stroke widths for different    * */
/* * icons at different camera distances.                                                                            * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

//+w128 +h128 +ua
//-f +w800 +h800

#version 3.7;

global_settings {assumed_gamma 2.2}

#local CameraZ = 3.98;

camera {
   orthographic
   location <0, 0, -CameraZ>
   direction <0, 0, 1>
   scale <1, 4/3, 1>
   look_at <0, 0, 0>
} //camera

#include "colors.inc"

#background {<135, 130, 102> / 255}

#local SymbolColor_Outer = texture {pigment {color White} finish {emission 1}}
#local SymbolColor_Inner = texture {pigment {color <102 * .91, 98 * .91, 76 * .92> / 255} finish {emission 1}}

#local StrokeWidth = .075; //Use .2 for website icon

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * MACROS                                                                                                          * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#macro Center_XY (Thing)

   #local Thing = object {Thing translate (-min_extent (Thing).x) * x}
   #local Thing = object {Thing translate (-max_extent (Thing).x / 2) * x}
   #local Thing = object {Thing translate (-max_extent (Thing).y) * y}
   #local Thing = object {Thing translate (-min_extent (Thing).y / 2) * y}

#end //#macro Center_XY

#macro MakeBasket (BasketWidth, BasketHeight, A0, A1, BasketRadius, Border)

   #local TempBasket = object {
      intersection {
         box {<-.6, 0, -.1> <BasketWidth - Border, BasketHeight - Border, 0>}
         plane {y, -Border rotate A0 * z} //Back
         plane {y, Border inverse rotate A1 * z} //Bottom
      } //intersection
   } //object

   #local TopCorner = object {
      difference {
         box {<0, 0, -.2> <BasketRadius + .1, BasketRadius + .1, .1>}
         cylinder {<0, 0, -.3>, <0, 0, .2>, BasketRadius - Border}
      } //difference
   } //object

   #local BottomCorner = object {
      difference {
         intersection {
            box {<0, 0, -.2> <BasketRadius + .1, -BasketRadius - .1, .1>}
            plane {y, 0 rotate (A1 + 90) * z}
         } //intersection
         cylinder {<0, 0, -.3>, <0, 0, .2>, BasketRadius - Border}
      } //difference
      #local BottomCornerDeltaY = tan (radians (A1)) * (BasketWidth - BasketRadius);
   } //object

   object {
      difference {
         object {TempBasket}
         object {TopCorner translate <BasketWidth - BasketRadius, BasketHeight - BasketRadius, 0>}
         object {BottomCorner translate <BasketWidth - BasketRadius, BottomCornerDeltaY + BasketRadius, 0>}
      } //difference
   } //object

#end //#macro MakeBasket

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * SYMBOLS                                                                                                         * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#local StrokeWidth = StrokeWidth * CameraZ / 4;

#local SW2 = StrokeWidth / 2;

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

//Object variables:

#local BasketWidth = 2.925;
#local BasketHeight = 1.725;
#local BasketRadius = .25;

#local HandleWidth = .725;
#local HandleHeight = .15;
#local HandleRadius = .45;

#local BaseHeight = .35;
#local BaseRadius = .12; //Should be > StrokeWidth for maximum detail

#local WheelHeight = .125;
#local WheelRadius = .5;
#local WheelX_Back = .35;
#local WheelX_Front = 2.1;

#local A0 = 103;
#local A1 = 5;
#local A2 = -135;

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#local Basket_Outer = object {MakeBasket (BasketWidth, BasketHeight, A0, A1, BasketRadius, 0) texture {SymbolColor_Outer}}
#local Basket_Inner = object {MakeBasket (BasketWidth, BasketHeight, A0, A1, BasketRadius, StrokeWidth) texture {SymbolColor_Inner}}

#local Basket = object {
   union {
      object {Basket_Outer}
      object {Basket_Inner translate -.1 * z}
   } //union
} //object

#local HandleHeight = BasketHeight + HandleHeight;

#local P0 = <HandleHeight / tan (radians (A0)), HandleHeight, 0>;
#local P1 = <(HandleRadius - StrokeWidth) * cos (radians (A0 - 90)), (HandleRadius - StrokeWidth) * sin (radians (A0 - 90)), 0>;

#local Handle_Bottom = object {
   intersection {
      box {<-.6, BasketHeight, -.1> <0, HandleHeight + .2, 0>}
      plane {y, 0 rotate A0 * z} //Back
      plane {y, -StrokeWidth inverse rotate A0 * z} //Front
      plane {y, 0 rotate (A0 - 90) * z translate P0}
   } //intersection
} //object

#local Handle_Curve = object {
   union {
      intersection {
         difference {
            cylinder {<0, 0, -.1> < 0, 0, 0>, HandleRadius}
            cylinder {<0, 0, -.2> < 0, 0, .1>, HandleRadius - StrokeWidth}
         } //difference
         plane {x, 0 inverse}
         plane {y, 0 inverse rotate (A0 - 90) * z}
      } //intersection
      box {<-HandleWidth, HandleRadius - StrokeWidth, -.1> <0, HandleRadius, 0>}
      cylinder {<0, 0, -.1> <0, 0, 0>, SW2 translate <-HandleWidth, HandleRadius - SW2, 0>}
   } //union
} //object

#local Handle = object {
   union {
      object {Handle_Bottom}
      object {Handle_Curve translate P0 - P1}
   } //union
   texture {SymbolColor_Outer}
} //object

#local P2 = <BaseHeight * cos (radians (A2)), BaseHeight * sin (radians (A2)), 0>;
#local P3 = <(BaseRadius - SW2) * cos (radians (A2 - 90)), (BaseRadius - SW2) * sin (radians (A2 - 90)), 0>;

#local BaseWidth = BasketWidth - SW2 + P3.x - P2.x;

#local Base_Top = object {
   intersection {
      box {<-.2, -SW2, -.1> <BaseHeight, SW2, 0> rotate A2 * z}
      plane {y, StrokeWidth rotate A1 * z} //Top
   } //intersection
} //object

#local Base_Curve = object {
   union {
      intersection {
         #if (StrokeWidth < BaseRadius)
            difference {
               cylinder {<0, 0, -.1> < 0, 0, 0>, BaseRadius}
               cylinder {<0, 0, -.2> < 0, 0, .1>, BaseRadius - StrokeWidth}
            } //difference
         #else
            cylinder {<0, 0, -.1> < 0, 0, 0>, BaseRadius}
         #end //#if
         plane {x, 0}
         plane {y, 0 inverse rotate (A2 - 90) * z}
      } //intersection
      box {<0, -BaseRadius, -.1> <BaseWidth, -BaseRadius + StrokeWidth, 0>}
      cylinder {<0, 0, -.1> <0, 0, 0>, SW2 translate <BaseWidth, -BaseRadius + SW2, 0>}
   } //union
} //object

#local Base = object {
   union {
      object {Base_Top}
      object {Base_Curve translate (P2 - P3)}
   } //union
   texture {SymbolColor_Outer}
} //object

#local WheelHeight = -WheelHeight - WheelRadius - BaseRadius + (P2.y - P3.y);

#local Wheel = object {
   union {
      cylinder {<0, 0, -.1> <0, 0, 0>, WheelRadius texture {SymbolColor_Outer}}
      cylinder {<0, 0, -.2> <0, 0, .1>, WheelRadius - StrokeWidth texture {SymbolColor_Inner}}
   } //union
   translate WheelHeight * y
} //object

#local ShoppingCart = object {
   union {
      object {Basket}
      object {Handle}
      object {Base}
      object {Wheel translate WheelX_Back * x}
      object {Wheel translate WheelX_Front * x}
   } //union
} //object

Center_XY (ShoppingCart)

object {ShoppingCart}
